@@ -194,7 +194,9 @@ class keydefaultdict(defaultdict):
         if self.default_factory is None:
             raise KeyError(key)
         else:
-            ret = self[key] = self.default_factory(key)
+            ret = self.default_factory(key)
+            if key != 'l':
+                self[key] = ret
             return ret
 
 
